@@ -1,12 +1,15 @@
 from src import securedb
 with open(".key", "r") as f:
     key = f.read()
-db = securedb.Db("db/example.sdb", bytes(key.encode()))
+db = securedb.Db("db/example.sdb", key, force=True)
+
 
 db.write("lol", 2)
 
-print(db.get_many(["lol", "lol1"]))
+
+print(db.get("lol"))
 
 db.delete("lol")
 
+
 print(db.get("lol"))
\ No newline at end of file
